import { BasicColumn, FormSchema } from '/@/components/Table';
import { h } from 'vue';
import { Tag } from 'ant-design-vue';

export const columns: BasicColumn[] = [
  {
    resizable: true,
    sorter: true,
    title: '货架',
    dataIndex: 'SHELF_CODE',
  },
  {
    resizable: true,
    sorter: true,
    title: '储位编码',
    dataIndex: 'LOCATION_CODE',
  },
  {
    resizable: true,
    sorter: true,
    title: '储位名称',
    dataIndex: 'LOCATION_NAME',
  },
  {
    resizable: true,
    sorter: true,
    title: '所处层数',
    dataIndex: 'FLOOR_NO',
  },
  {
    resizable: true,
    sorter: true,
    title: '是否使用',
    dataIndex: 'ISUSE',
    customRender: ({ record }) => {
      const status = record.ISUSE;
      const enable = status === 'Y';
      const color = enable ? 'green' : 'red';
      const text = enable ? '使用' : '不可用';
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    resizable: true,
    sorter: true,
    title: '是否混放',
    dataIndex: 'ISMIX',
    customRender: ({ record }) => {
      const status = record.ISMIX;
      const enable = status === 'Y';
      const color = enable ? 'green' : 'red';
      const text = enable ? '混放' : '否';
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    resizable: true,
    sorter: true,
    title: '是否损坏',
    dataIndex: 'IS_DAMAGE',
    customRender: ({ record }) => {
      const status = record.ISMIX;
      const enable = status === 'Y';
      const color = enable ? 'red' : 'green';
      const text = enable ? '损坏' : '完好';
      return h(Tag, { color: color }, () => text);
    },
  },
  {
    resizable: true,
    sorter: true,
    title: '方向',
    dataIndex: 'SEQ_NO',
  },
  {
    resizable: true,
    sorter: true,
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    width: 180,
  },
  {
    resizable: true,
    sorter: true,
    title: '备注',
    dataIndex: 'REMARK',
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'SHELF_CODE',
    label: '货架',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'LOCATION_CODE',
    label: '储位编码',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'LOCATION_NAME',
    label: '储位名称',
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'FLOOR_NO',
    label: '所处层数',
    component: 'Input',
    colProps: { span: 8 },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'SHELF_CODE',
    label: '货架值',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'LOCATION_CODE',
    label: '储位编码',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'LOCATION_NAME',
    label: '储位名称',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'FLOOR_NO',
    label: '所处层数',
    // required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'FLOOR_COUNT',
    label: '每层储位数',
    // required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'SIDE',
    label: '储位方向',
    required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'ISUSE',
    label: '是否使用',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'ISMIX',
    label: '是否混放',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'IS_DAMAGE',
    label: '是否损坏',
    required: true,
    component: 'Select',
    colProps: { span: 8 },
    componentProps: {
      options: [
        {
          label: '是',
          value: 'Y',
          key: 'Y',
        },
        {
          label: '否',
          value: 'N',
          key: 'N',
        },
      ],
    },
  },
  {
    field: 'SEQ_NO',
    label: '储位序号',
    // required: true,
    component: 'Input',
    colProps: { span: 8 },
  },
  {
    field: 'REMARK',
    label: '备注',
    // required: true,
    component: 'Input',
    colProps: { span: 24 },
  },
];
